//
//  ViewController.m
//  Twirl
//
//  Created by Craig Hockenberry on 10/24/17.
//  Copyright © 2017 The Iconfactory. All rights reserved.
//

#import "ViewController.h"

@interface ViewController ()

@property (nonatomic, weak) IBOutlet NSPopUpButton *accountPopUpButton;

@property (nonatomic, weak) IBOutlet NSComboBox *profileScreenNameComboBox;
@property (nonatomic, weak) IBOutlet NSComboBox *tweetIdComboBox;
@property (nonatomic, weak) IBOutlet NSComboBox *searchQueryComboBox;
@property (nonatomic, weak) IBOutlet NSComboBox *listNameComboBox;
@property (nonatomic, weak) IBOutlet NSComboBox *recipientIdComboBox;
@property (nonatomic, weak) IBOutlet NSComboBox *muffleAddComboBox;

@property (nonatomic, weak) IBOutlet NSTextField *messageTextField;
@property (nonatomic, weak) IBOutlet NSComboBox *replyIdComboBox;

@end

@implementation ViewController

- (void)openURLWithFunction:(NSString *)functionName parameters:(NSString *)parameters
{
	NSURL *URL = nil;
	
	NSString *accountName = nil;
	
	NSString *selectedTitle = self.accountPopUpButton.selectedItem.title;
	if ([selectedTitle isEqual:@"None"]) {
		accountName = @"";
	}
	else if ([selectedTitle isEqual:@"Current"]) {
		accountName = @"current";
	}
	else {
		accountName = [@"account/" stringByAppendingString:selectedTitle];
	}

	NSString *scheme = @"twitterrific5:"; // "twitterrific:" can also be used, but older versions may not support all the functions shown here
	
	NSString *URLString = [NSString stringWithFormat:@"%@//%@/%@", scheme, accountName, functionName];
	if (parameters) {
		URLString = [NSString stringWithFormat:@"%@?%@", URLString, [parameters stringByAddingPercentEncodingWithAllowedCharacters:[NSCharacterSet URLQueryAllowedCharacterSet]]];
	}
	URL = [NSURL URLWithString:URLString];

	NSLog(@"URLString = %@, URL = %@", URLString, URL);
	
	[NSWorkspace.sharedWorkspace openURL:URL];
}

#pragma mark -

- (IBAction)tweets:(id)sender
{
	[self openURLWithFunction:@"tweets" parameters:nil];
}

- (IBAction)mentions:(id)sender
{
	[self openURLWithFunction:@"mentions" parameters:nil];
}

- (IBAction)messages:(id)sender
{
	[self openURLWithFunction:@"messages" parameters:nil];
}

- (IBAction)favorites:(id)sender
{
	[self openURLWithFunction:@"favorites" parameters:nil];
}

#pragma mark -

- (IBAction)profile:(id)sender
{
	NSString *screenName = self.profileScreenNameComboBox.stringValue;
	NSString *parameters = [@"screen_name=" stringByAppendingString:screenName];
	[self openURLWithFunction:@"profile" parameters:parameters];
}

- (IBAction)tweet:(id)sender
{
	NSString *id = self.tweetIdComboBox.stringValue;
	NSString *parameters = [@"id=" stringByAppendingString:id];
	[self openURLWithFunction:@"tweet" parameters:parameters];
}

- (IBAction)search:(id)sender
{
	NSString *query = self.searchQueryComboBox.stringValue;
	NSString *parameters = [@"q=" stringByAppendingString:query];
	[self openURLWithFunction:@"search" parameters:parameters];
}

- (IBAction)list:(id)sender
{
	NSString *name = self.listNameComboBox.stringValue;
	NSString *parameters = [@"name=" stringByAppendingString:name];
	[self openURLWithFunction:@"list" parameters:parameters];
}

- (IBAction)send:(id)sender
{
	NSString *recipientId = self.recipientIdComboBox.stringValue;
	NSString *parameters = [@"recipient_id=" stringByAppendingString:recipientId];
	[self openURLWithFunction:@"send" parameters:parameters];
}

- (IBAction)muffle:(id)sender
{
	NSString *add = self.muffleAddComboBox.stringValue;
	NSString *parameters = [@"add=" stringByAppendingString:add];
	[self openURLWithFunction:@"muffle" parameters:parameters];
}

#pragma mark -

- (IBAction)post:(id)sender
{
	NSString *parameters = @"";
	
	NSString *message = self.messageTextField.stringValue;
	parameters = [parameters stringByAppendingString:[@"message=" stringByAppendingString:message]];
	NSString *replyId = self.replyIdComboBox.stringValue;
	if (replyId && replyId.length > 0) {
		parameters = [parameters stringByAppendingString:@"&"];
		parameters = [parameters stringByAppendingString:[@"reply_to_id=" stringByAppendingString:replyId]];
	}
	[self openURLWithFunction:@"post" parameters:parameters];
}

@end
